@@ -304,6 +304,51 @@ class DecimalGenerator(Generator):
         return value
 
 
+class FirstNameGenerator(Generator):
+    """ Generates a first name, either male or female """
+
+    male = [
+        'Abraham', 'Adam', 'Anthony', 'Brian', 'Bill', 'Ben', 'Calvin',
+        'David', 'Daniel', 'George', 'Henry', 'Isaac', 'Ian', 'Jonathan',
+        'Jeremy', 'Jacob', 'John', 'Jerry', 'Joseph', 'James', 'Larry',
+        'Michael', 'Mark', 'Paul', 'Peter', 'Phillip', 'Stephen', 'Tony',
+        'Titus', 'Trevor', 'Timothy', 'Victor', 'Vincent', 'Winston', 'Walt']
+    female = [
+        'Abbie', 'Anna', 'Alice', 'Beth', 'Carrie', 'Christina' 'Danielle',
+        'Emma', 'Emily', 'Esther', 'Felicia', 'Grace', 'Gloria', 'Helen',
+        'Irene', 'Joanne', 'Joyce', 'Jessica', 'Kathy', 'Katie', 'Kelly',
+        'Linda', 'Lydia', 'Mandy', 'Mary', 'Olivia', 'Priscilla',
+        'Rebecca', 'Rachel', 'Susan', 'Sarah', 'Stacey', 'Vivian']
+
+    def __init__(self, gender=None):
+        self.gender = gender
+        self.all = self.male + self.female
+
+    def generate(self):
+        if self.gender == 'm':
+            return random.choice(self.male)
+        elif self.gender == 'f':
+            return random.choice(self.female)
+        else:
+            return random.choice(self.all)
+
+
+class LastNameGenerator(Generator):
+    """ Generates a last name """
+    
+    surname = [
+        'Smith', 'Walker', 'Conroy', 'Stevens', 'Jones', 'Armstrong',
+        'Johnson', 'White', 'Stone', 'Strong', 'Olson', 'Lee', 'Forrest',
+        'Baker', 'Portman', 'Davis', 'Clark', 'Brown', 'Roberts', 'Ellis',
+        'Jackson', 'Marshall', 'Wang', 'Chen', 'Chou', 'Tang', 'Huang', 'Liu',
+        'Shih', 'Su', 'Song', 'Yang', 'Chan', 'Tsai', 'Wong', 'Hsu', 'Cheng',
+        'Chang', 'Wu', 'Lin', 'Yu', 'Yao', 'Kang', 'Park', 'Kim', 'Choi',
+        'Ahn', 'Mujuni']
+
+    def generate(self):
+        return random.choice(self.surname)
+
+
 class EmailGenerator(StringGenerator):
     chars = string.ascii_lowercase
 
